==> blender-2.26.tar.bz2: blender-2.26/source/gameengine/Ketsji/KX_ISystem.h <==
/**
* Abstract system
*
* $Id: KX_ISystem.h,v 1.5 2002/12/27 13:10:48 mein Exp $
*
 * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. The Blender
 * Foundation also sells licenses for use in proprietary software under
 * the Blender License.  See http://www.blender.org/BL/ for information
 * about this.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL/BL DUAL LICENSE BLOCK *****
*/

#ifndef __KX_ISYSTEM
#define __KX_ISYSTEM

#include <vector>
using namespace std;

#include "STR_String.h"

/**
 * System Abstraction, needed only for getting some timing stuff from the host.
 */
class KX_ISystem
{
public:
	KX_ISystem() {};
	virtual ~KX_ISystem() {};
	
	virtual double GetTimeInSeconds()=0;
};

#endif

==> blender_2.62.orig.tar.bz2: blender-2.62/source/gameengine/Ketsji/KX_ISystem.h <==
/*
 * ***** BEGIN GPL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL LICENSE BLOCK *****
 */

/** \file KX_ISystem.h
 *  \ingroup ketsji
 *  \brief Abstract system
 */

#ifndef __KX_ISYSTEM
#define __KX_ISYSTEM

#include <vector>
using namespace std;

#include "STR_String.h"

#ifdef WITH_CXX_GUARDEDALLOC
#include "MEM_guardedalloc.h"
#endif

/**
 * System Abstraction, needed only for getting some timing stuff from the host.
 */
class KX_ISystem
{
public:
	KX_ISystem() {};
	virtual ~KX_ISystem() {};
	
	virtual double GetTimeInSeconds()=0;


#ifdef WITH_CXX_GUARDEDALLOC
public:
	void *operator new(size_t num_bytes) { return MEM_mallocN(num_bytes, "GE:KX_ISystem"); }
	void operator delete( void *mem ) { MEM_freeN(mem); }
#endif
};

#endif
